Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/kornelski/7z.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'CPP/7zip/Crypto/HmacSha1.h')
-rw-r--r--CPP/7zip/Crypto/HmacSha1.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/CPP/7zip/Crypto/HmacSha1.h b/CPP/7zip/Crypto/HmacSha1.h
index d7181329..6ba015e8 100644
--- a/CPP/7zip/Crypto/HmacSha1.h
+++ b/CPP/7zip/Crypto/HmacSha1.h
@@ -4,7 +4,7 @@
#ifndef __CRYPTO_HMAC_SHA1_H
#define __CRYPTO_HMAC_SHA1_H
-#include "Sha1.h"
+#include "Sha1Cls.h"
namespace NCrypto {
namespace NSha1 {
@@ -28,9 +28,9 @@ class CHmac32
public:
void SetKey(const Byte *key, size_t keySize);
void Update(const UInt32 *data, size_t dataSize) { _sha.Update(data, dataSize); }
- void Final(UInt32 *mac, size_t macSize = kDigestSizeInWords);
+ void Final(UInt32 *mac, size_t macSize = kNumDigestWords);
- // It'sa for hmac function. in,out: mac[kDigestSizeInWords].
+ // It'sa for hmac function. in,out: mac[kNumDigestWords].
void GetLoopXorDigest(UInt32 *mac, UInt32 numIteration);
};